%%%%%%%%%%%%%%%%%
% main_tur_ur.m %
%%%%%%%%%%%%%%%%%

% This Matlab program estimates a TAR(p+1).
% It tests for a threshold and for unit roots.

% written by:

% Bruce E. Hansen
% Department of Economics
% Social Science Building
% University of Wisconsin
% Madison, WI 53706-1393
% bhansen@ssc.wisc.edu
% http://www.ssc.wisc.edu/~bhansen/


% This program reproduces the empirical application reported in
% "Threshold Autoregression with a Near Unit Root"
% by Mehmet Caner and Bruce E. Hansen.
% To run this program as it is set, you need the data files
% lhmu.txt and lhmc.txt
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%55

global thresh_;
global trim_;trim_=1;
global graph_;graph_=1;
global trend_;trend_=0;
global boot_;
global adj_;adj_=0;
global xdate_;
global test_;test_=0;

load lhmu.txt;
y1=lhmu(1)-.01+(1/12);
lhmu=lhmu(3:length(lhmu(:,1)));
load lhmc.txt;
lhmc=lhmc(3:length(lhmc(:,1)));
dat=(lhmu./lhmc)*100;
fst=97;
dat=dat(fst:length(dat(:,1)));
y1=y1+(fst-1)/12;
thresh_=1;
trim_=1;
trend_=0;
test_=(3:1:12)';
p=12;
mmin=1;
mmax=12;
m=9;
 
% No transformation %
yy=dat;
 
xdate_=((y1+(p+1)/12):(1/12):((y1+(p+1)/12)+(length(dat(:,1))-p-2)*(1/12)));
% These are the x-axis values for the graph set _xdate=0  if undated
% x-axis is okay %
disp('*************************************');
disp('* U.S. Adult Male Unemployment Rate *');
disp('*************************************');
tar_ur(yy,p,mmin,mmax,m);
  
graph_=0;
% First Half Sample %
adj_=0;
yy=dat(1:(floor(length(dat(:,1))/2)));
disp('***********************************');
disp('* Unemployment Rate, First Sample *');
disp('***********************************');
tar_ur(yy,p,mmin,mmax,m);


% First Half Sample %
adj_=0;
yy=dat((floor(length(dat(:,1))/2)+1):length(dat(:,1)));
date1_=y1+floor(length(dat(:,1))/2)/12;
disp('************************************');
disp('* Unemployment Rate, Second Sample *');
disp('************************************');
tar_ur(yy,p,mmin,mmax,m);
date1_=y1;

% logit transformation x=log(u/(100-u)) %
ldat=log(dat./(100-dat));
adj_=sum(log((100./dat)./(100-dat))')';
yy=ldat;
disp('******************************');
disp('* Logistic Unemployment Rate *');
disp('******************************');
tar_ur(yy,p,mmin,mmax,m);

% log transformation   x=log(u) %
ldat=log(dat);
adj_=sum(-log(dat))';
yy=ldat;
disp('*************************');
disp('* Log Unemployment Rate *');
disp('*************************');
tar_ur(yy,p,mmin,mmax,m);

% log-type transformation x=-100*log(1-u/100) %
ldat=-log(1-dat/100)*100;
adj_=sum(-log(1-dat/100))';
yy=ldat;
disp('******************************');
disp('* Log-Type Unemployment Rate *');
disp('******************************');
tar_ur(yy,p,mmin,mmax,m);

% exp transformation   x=exp(u/100) %
ldat=(exp(dat/100)-1)*100;
adj_=sum(dat/100)';
yy=ldat;
disp('*************************');
disp('* Exp Unemployment Rate *');
disp('*************************');
tar_ur(yy,p,mmin,mmax,m);

% Alternative Trimming %
trim_=2;
adj_=0;
yy=dat;
disp('*************************************');
disp('* U.S. Adult Male Unemployment Rate *');
disp('*************************************');
tar_ur(yy,p,mmin,mmax,m);
trim_=3;
disp('*************************************');
disp('* U.S. Adult Male Unemployment Rate *');
disp('*************************************');
tar_ur(yy,p,mmin,mmax,m);

% Include Linear Trend %
trim_=1;
trend_=1;
disp('*************************************');
disp('* U.S. Adult Male Unemployment Rate *');
disp('*************************************');
tar_ur(yy,p,mmin,mmax,m);